@@ -33,17 +33,15 @@
 #include <vigra_ext/utils.h>
 #include <panodata/Panorama.h>
 
-using namespace std;
-
 namespace celeste
 {
 
 /** loads the SVM model from file
- *  @param model struct, which stores the SVM informations, if you don't need it, call destroySVMmodel
+ *  @param model struct, which stores the SVM information, if you don't need it, call destroySVMmodel
  *  @param model_file filename of model file to load
  *  @return true, if loading of SVM file was sucessfull
  */
-CELESTEIMPEX bool loadSVMmodel(struct svm_model*& model, string& model_file);
+CELESTEIMPEX bool loadSVMmodel(struct svm_model*& model, std::string& model_file);
 /** frees the resource of model
  *  @param model SVM model struct to freeing 
  */
@@ -58,7 +56,7 @@ CELESTEIMPEX void destroySVMmodel(struct svm_model*& model);
  *  @param adaptThreshold if true then the threshold is changed, if the all values are higher than threshold
  *  @return vigra::BImage, which contains the masks
  */
-CELESTEIMPEX vigra::BImage getCelesteMask(struct svm_model* model, vigra::UInt16RGBImage& input, int radius, float threshold, int resize_dimension,bool adaptThreshold=false,bool verbose=true);
+CELESTEIMPEX vigra::BImage* getCelesteMask(struct svm_model* model, vigra::UInt16RGBImage& input, int radius, float threshold, int resize_dimension,bool adaptThreshold=false,bool verbose=true);
 
 CELESTEIMPEX HuginBase::UIntSet getCelesteControlPoints(struct svm_model* model, vigra::UInt16RGBImage& input, HuginBase::CPointVector cps, int radius, float threshold, int resize_dimension,bool verbose=true);
 
