@@ -71,11 +71,23 @@ class HuginExecutor : public APP
         m_locale.AddCatalogLookupPathPrefix(exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR) + wxT("share\\locale"));
 #elif defined __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
         // nothing to do
+#elif defined UNIX_SELF_CONTAINED_BUNDLE
+        // initialize paths
+        {
+          wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
+          exePath.RemoveLastDir();
+          const wxString huginRoot=exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
+          // add the locale directory specified during configure
+          m_locale.AddCatalogLookupPathPrefix(huginRoot + wxT("share/locale"));
+        }
 #else
         // add the locale directory specified during configure
         m_locale.AddCatalogLookupPathPrefix(wxT(INSTALL_LOCALE_DIR));
 #endif
         // init our config settings
+#if defined __WXGTK__ && wxCHECK_VERSION(3,1,1)
+        CheckConfigFilename();
+#endif
         wxConfig* config = new wxConfig(wxT("hugin"));
         wxConfigBase::Set(config);
 
@@ -123,7 +135,7 @@ class HuginExecutor : public APP
             }
             else
             {
-                commands = HuginQueue::GetAssistantCommandQueueUserDefined(pano, m_utilsBinDir, m_input, m_userAssistant);
+                commands = HuginQueue::GetAssistantCommandQueueUserDefined(pano, m_utilsBinDir, m_input, m_userAssistant, tempfiles, std::cerr);
             };
         }
         else
@@ -145,11 +157,11 @@ class HuginExecutor : public APP
             wxArrayString outputFiles;
             if (m_userOutput.IsEmpty())
             {
-                commands = HuginQueue::GetStitchingCommandQueue(pano, m_utilsBinDir, inputFile.GetFullPath(), outputPrefix.GetName(), statusText, outputFiles, tempfiles);
+                commands = HuginQueue::GetStitchingCommandQueue(pano, m_utilsBinDir, inputFile.GetFullPath(), outputPrefix.GetName(), statusText, outputFiles, tempfiles, std::cerr);
             }
             else
             {
-                commands = HuginQueue::GetStitchingCommandQueueUserOutput(pano, m_utilsBinDir, inputFile.GetFullPath(), outputPrefix.GetName(), m_userOutput, statusText, outputFiles, tempfiles);
+                commands = HuginQueue::GetStitchingCommandQueueUserOutput(pano, m_utilsBinDir, inputFile.GetFullPath(), outputPrefix.GetName(), m_userOutput, statusText, outputFiles, tempfiles, std::cerr);
             };
             if (!m_dryRun)
             {
@@ -184,7 +196,7 @@ class HuginExecutor : public APP
             {
                 // short waiting time to write all files to disc
                 wxMilliSleep(100);
-                std::cout << _("Removing temporary files...") << std::endl;
+                std::cout << _("Removing temporary files") << std::endl;
                 for (size_t i = 0; i < tempfiles.size(); ++i)
                 {
                     wxRemoveFile(tempfiles[i]);
@@ -242,9 +254,14 @@ class HuginExecutor : public APP
                     userOutputFile.SetPath(wxString(hugin_utils::GetDataDir().c_str(), HUGIN_CONV_FILENAME));
                     if (!userOutputFile.FileExists())
                     {
-                        std::cerr << "ERROR: File \"" << m_userOutput.mb_str(wxConvLocal) << "\" does not exists." << std::endl
-                            << "       Also tried file \"" << userOutputFile.GetFullPath().mb_str(wxConvLocal) << "\", which does also not exists." << std::endl;
-                        return false;
+                        const wxString testedFile1 = userOutputFile.GetFullPath();
+                        userOutputFile.SetPath(wxString(hugin_utils::GetUserAppDataDir().c_str(), HUGIN_CONV_FILENAME));
+                        if (!userOutputFile.FileExists())
+                        {
+                            std::cerr << "ERROR: File \"" << m_userOutput.mb_str(wxConvLocal) << "\" does not exists." << std::endl
+                                << "       Also tried files \"" << testedFile1.mb_str(wxConvLocal) << "\" and \"" << userOutputFile.GetFullPath().mb_str(wxConvLocal) << "\", which don't exist." << std::endl;
+                            return false;
+                        };
                     }
                     m_userOutput = userOutputFile.GetFullPath();
                 }
@@ -267,9 +284,14 @@ class HuginExecutor : public APP
                     userAssistantFile.SetPath(wxString(hugin_utils::GetDataDir().c_str(), HUGIN_CONV_FILENAME));
                     if (!userAssistantFile.FileExists())
                     {
-                        std::cerr << "ERROR: File \"" << m_userAssistant.mb_str(wxConvLocal) << "\" does not exists." << std::endl
-                            << "       Also tried file \"" << userAssistantFile.GetFullPath().mb_str(wxConvLocal) << "\", which does also not exists." << std::endl;
-                        return false;
+                        const wxString testedFile1 = userAssistantFile.GetFullPath();
+                        userAssistantFile.SetPath(wxString(hugin_utils::GetUserAppDataDir().c_str(), HUGIN_CONV_FILENAME));
+                        if (!userAssistantFile.FileExists())
+                        {
+                            std::cerr << "ERROR: File \"" << m_userAssistant.mb_str(wxConvLocal) << "\" does not exists." << std::endl
+                                << "       Also tried files \"" << testedFile1.mb_str(wxConvLocal) << "\" and \"" << userAssistantFile.GetFullPath().mb_str(wxConvLocal) << "\", which don't exist." << std::endl;
+                            return false;
+                        };
                     }
                     m_userAssistant = userAssistantFile.GetFullPath();
                 }
