@@ -38,7 +38,11 @@ extern "C"
 #if !(defined HAVE_STD_FILESYSTEM)
 #include "boost/version.hpp"
 #endif
-#include "exiv2/exiv2.hpp"
+#ifdef _WIN32
+// workaround for a conflict between exiv2 and wxWidgets/CMake built
+#define HAVE_PID_T 1
+#endif
+#include <exiv2/exiv2.hpp>
 #include "lensdb/LensDB.h"
 #include "sqlite3.h"
 #include <lcms2.h>
@@ -206,7 +210,7 @@ void AboutDialog::GetSystemInformation(wxFont *font)
 #if !(defined HAVE_STD_FILESYSTEM)
     text=text+wxT("\n")+wxString::Format(wxT("Boost: %i.%i.%i"),BOOST_VERSION / 100000, BOOST_VERSION / 100 % 1000, BOOST_VERSION % 100);
 #endif
-    text = text + wxT("\n") + wxT("Exiv2: ") + wxString(Exiv2::version(), wxConvLocal);
+    text = text + wxT("\n") + wxT("Exiv2: ") + wxString(Exiv2::versionString().c_str(), wxConvLocal);
     text = text + wxT("\n") + wxT("SQLite3: ") + wxString(sqlite3_libversion(), wxConvLocal);
     text = text + wxT("\n") + wxString::Format(wxT("Vigra: %s"), wxString(VIGRA_VERSION, wxConvLocal).c_str());
     text = text + wxT("\n") + wxString::Format(wxT("LittleCMS2: %i.%i"), LCMS_VERSION / 1000, LCMS_VERSION / 10 % 100);
