@@ -25,8 +25,13 @@
  *
  */
 
+#ifdef _WIN32
+#include "wx/msw/wrapwin.h"
+ // Mingw define still DIFFERENCE, which conflicts with vigra, so disable it
+#undef DIFFERENCE
+#endif
 #include "hugin/CPDetectorDialog.h"
-#include <config.h>
+#include "hugin_config.h"
 #include "base_wx/huginConfig.h"
 #include "hugin/config_defaults.h"
 #include "hugin/huginApp.h"
@@ -76,13 +81,11 @@ CPDetectorDialog::CPDetectorDialog(wxWindow* parent)
     m_check_option = XRCCTRL(*this, "prefs_cpdetector_option", wxCheckBox);
     m_cpdetector_type = XRCCTRL(*this, "prefs_cpdetector_type", wxChoice);
     m_choice_step = XRCCTRL(*this, "choicebook_steps", wxChoicebook);
-#if wxCHECK_VERSION(2,9,3)
     // enable auto completion
     m_edit_prog->AutoCompleteFileNames();
     m_edit_prog_descriptor->AutoCompleteFileNames();
     m_edit_prog_matcher->AutoCompleteFileNames();
     m_edit_prog_stack->AutoCompleteFileNames();
-#endif
     m_cpdetector_type->SetSelection(1);
     ChangeType();
 };
