@@ -78,6 +78,9 @@ BEGIN_EVENT_TABLE(ImagesTreeCtrl, wxTreeListCtrl)
     EVT_TREE_KEY_DOWN(-1, ImagesTreeCtrl::OnChar)
     EVT_TREE_BEGIN_LABEL_EDIT(-1, ImagesTreeCtrl::OnBeginEdit)
     EVT_TREE_END_LABEL_EDIT(-1, ImagesTreeCtrl::OnEndEdit)
+#if wxCHECK_VERSION(3,1,3)
+    EVT_DPI_CHANGED(ImagesTreeCtrl::OnDpiChanged)
+#endif
 END_EVENT_TABLE()
 
 class ImagesTreeData : public wxTreeItemData
@@ -408,86 +411,11 @@ void ImagesTreeCtrl::UpdateImageText(wxTreeItemId item)
     SetItemText(item, m_columnMap["maker"], wxString(img.getExifMake().c_str(), wxConvLocal));
     SetItemText(item, m_columnMap["model"], wxString(img.getExifModel().c_str(), wxConvLocal));
     SetItemText(item, m_columnMap["lens"], wxString(img.getExifLens().c_str(), wxConvLocal));
-    struct tm exifdatetime;
-    if(img.getExifDateTime(&exifdatetime)==0)
-    {
-        wxDateTime s_datetime=wxDateTime(exifdatetime);
-        s=s_datetime.Format();
-    }
-    else
-    {
-        s = wxString(img.getExifDate().c_str(),wxConvLocal);
-    }
-    SetItemText(item, m_columnMap["date"], s);
-
-    if(img.getExifFocalLength()>0.0)
-    {
-        if(img.getExifFocalLength35()>0.0)
-        {
-            s = wxString::Format(wxT("%0.1f mm (%0.0f mm)"),img.getExifFocalLength(),img.getExifFocalLength35());
-        }
-        else
-        {
-            s = wxString::Format(wxT("%0.1f mm"),img.getExifFocalLength());
-        };
-    }
-    else
-    {
-        s = wxEmptyString;
-    };
-    SetItemText(item, m_columnMap["focallength"], s);
-
-    if(img.getExifAperture()>0)
-    {
-        s=wxString::Format(wxT("F%.1f"),img.getExifAperture());
-    }
-    else
-    {
-        s=wxEmptyString;
-    };
-    SetItemText(item, m_columnMap["aperture"], s);
-
-    if(img.getExifExposureTime()>0.5)
-    {
-        if(img.getExifExposureTime()>=1.0) 
-        {
-            if(img.getExifExposureTime()>=10.0) 
-            {
-                s=wxString::Format(wxT("%3.0f s"),img.getExifExposureTime());
-            }
-            else
-            {
-                s=wxString::Format(wxT("%1.1f s"),img.getExifExposureTime());
-            }
-        }
-        else
-        {
-            s=wxString::Format(wxT("%1.2f s"),img.getExifExposureTime());
-        }
-    }
-    else
-    {
-        if (img.getExifExposureTime() > 1e-9)
-        {
-            s=wxString::Format(wxT("1/%0.0f s"),1.0/img.getExifExposureTime());
-        } 
-        else
-        {
-            //Sanity
-            s=wxT("");
-        }
-    }
-    SetItemText(item, m_columnMap["time"], s);
-
-    if(img.getExifISO()>0)
-    {
-        s=wxString::Format(wxT("%0.0f"),img.getExifISO());
-    }
-    else
-    {
-        s=wxEmptyString;
-    };
-    SetItemText(item, m_columnMap["iso"], s);
+    SetItemText(item, m_columnMap["date"], FormatString::GetExifDateTime(&img));
+    SetItemText(item, m_columnMap["focallength"], FormatString::GetFocalLength(&img));
+    SetItemText(item, m_columnMap["aperture"], FormatString::GetAperture(&img));
+    SetItemText(item, m_columnMap["time"], FormatString::GetExposureTime(&img));
+    SetItemText(item, m_columnMap["iso"], FormatString::GetIso(&img));
 
     if (m_groupMode == GROUP_STACK && (img.YawisLinked() || isSingleImage))
     {
@@ -927,7 +855,7 @@ void ImagesTreeCtrl::UpdateOptimizerVariables()
         {
             imgNrs.insert(data->GetImgNr());
         };
-        if(imgNrs.size()>0)
+        if(!imgNrs.empty())
         {
             for(size_t i=0;i<GetColumnCount();i++)
             {
@@ -1017,12 +945,8 @@ void ImagesTreeCtrl::SetGuiLevel(GuiLevel newSetting)
     SetDisplayMode(m_displayMode);
 };
 
-void ImagesTreeCtrl::SetOptimizerMode()
+void ImagesTreeCtrl::CreateCheckboxImages()
 {
-    m_optimizerMode=true;
-    // connnect events with handlers
-    Bind(wxEVT_MOTION, &ImagesTreeCtrl::OnMouseMove, this);
-    Bind(wxEVT_LEFT_DOWN, &ImagesTreeCtrl::OnLeftDown, this);
     //create bitmaps for different checkboxes state
     wxRendererNative& renderer = wxRendererNative::Get();
     const wxSize checkBoxSize = renderer.GetCheckBoxSize(this);
@@ -1054,6 +978,16 @@ void ImagesTreeCtrl::SetOptimizerMode()
     checkboxImageList->Add(checkBoxImage);
 
     AssignImageList(checkboxImageList);
+}
+
+void ImagesTreeCtrl::SetOptimizerMode()
+{
+    m_optimizerMode=true;
+    // connnect events with handlers
+    Bind(wxEVT_MOTION, &ImagesTreeCtrl::OnMouseMove, this);
+    Bind(wxEVT_LEFT_DOWN, &ImagesTreeCtrl::OnLeftDown, this);
+    // build image list with check box images
+    CreateCheckboxImages();
     // activate edit mode
     for(HuginBase::UIntSet::const_iterator it=m_editableColumns.begin(); it!=m_editableColumns.end(); ++it)
     {
@@ -1062,7 +996,19 @@ void ImagesTreeCtrl::SetOptimizerMode()
             SetColumnEditable(*it,true);
         };
     };
-};
+}
+
+#if wxCHECK_VERSION(3,1,3)
+void ImagesTreeCtrl::OnDpiChanged(wxDPIChangedEvent& e)
+{
+    // dpi has changed, we need to update the images of the checkboxes
+    if (m_optimizerMode)
+    {
+        CreateCheckboxImages();
+        Refresh();
+    };
+}
+#endif
 
 void ImagesTreeCtrl::SetGroupMode(GroupMode newGroup)
 {
@@ -1084,6 +1030,8 @@ void ImagesTreeCtrl::SetGroupMode(GroupMode newGroup)
             fill_set(imgs,0,m_pano->getNrOfImages()-1);
         };
         panoramaImagesChanged(*m_pano,imgs);
+        // reset already modified tag
+        m_needsUpdate = true;
         ExpandAll(m_root);
     };
 };
@@ -1158,8 +1106,20 @@ void ImagesTreeCtrl::OnContextMenu(wxTreeEvent & e)
         {
             bool emptyText=GetItemText(e.GetItem(),m_selectedColumn).IsEmpty();
             ImagesTreeData* data=static_cast<ImagesTreeData*>(GetItemData(e.GetItem()));
-            if((m_groupMode==GROUP_LENS && m_variableVector[m_selectedColumn]!=HuginBase::ImageVariableGroup::IVE_Yaw) ||
-               (m_groupMode==GROUP_STACK && m_variableVector[m_selectedColumn]==HuginBase::ImageVariableGroup::IVE_Yaw) )
+            bool varIsLinkable = false;
+            if (m_groupMode == GROUP_LENS)
+            {
+                varIsLinkable = m_variableVector[m_selectedColumn] != HuginBase::ImageVariableGroup::IVE_Yaw &&
+                    set_contains(HuginBase::ConstStandardImageVariableGroups::getLensVariables(), m_variableVector[m_selectedColumn]);
+            }
+            else
+            {
+                if (m_groupMode == GROUP_STACK)
+                {
+                    varIsLinkable = m_variableVector[m_selectedColumn] == HuginBase::ImageVariableGroup::IVE_Yaw;
+                }
+            };
+            if(varIsLinkable)
             {
                 if(data->IsGroup())
                 {
@@ -1435,7 +1395,7 @@ void ImagesTreeCtrl::OnDeactivateImage(wxCommandEvent & e)
 void ImagesTreeCtrl::UnLinkImageVariables(bool linked)
 {
     HuginBase::UIntSet images=GetSelectedImages();
-    if(images.size()>0 && m_variableVector[m_selectedColumn]!=HuginBase::ImageVariableGroup::IVE_Filename)
+    if(!images.empty() && m_variableVector[m_selectedColumn]!=HuginBase::ImageVariableGroup::IVE_Filename)
     {
         std::set<HuginBase::ImageVariableGroup::ImageVariableEnum> variables;
         variables.insert(m_variableVector[m_selectedColumn]);
@@ -1477,7 +1437,7 @@ void ImagesTreeCtrl::OnUnlinkImageVariables(wxCommandEvent &e)
 void ImagesTreeCtrl::OnEditImageVariables(wxCommandEvent &e)
 {
     HuginBase::UIntSet imgs=GetSelectedImages();
-    if(imgs.size()>0)
+    if(!imgs.empty())
     {
         ImageVariableDialog dlg(this, m_pano, imgs);
         dlg.SetGuiLevel(m_guiLevel);
@@ -1516,7 +1476,7 @@ void ImagesTreeCtrl::OnBeginDrag(wxTreeEvent &e)
     if(m_pano->getNrOfImages()>0 && !m_dragging)
     {
         m_draggingImages=GetSelectedImages();
-        if(m_draggingImages.size()>0)
+        if(!m_draggingImages.empty())
         {
             if((m_groupMode==GROUP_NONE && m_draggingImages.size()==1 && !ctrlPressed) ||
                 m_groupMode==GROUP_LENS || m_groupMode==GROUP_STACK)
@@ -1934,12 +1894,22 @@ void ImagesTreeCtrl::SelectAllParameters(bool select, bool allImages)
             if(select)
             {
                 if((*it=="y" || *it=="p" || *it=="r" || *it=="TrX" || *it=="TrY" || *it=="TrZ" || *it=="Tpy" || *it=="Tpp") && 
-                    *img==m_pano->getOptions().optimizeReferenceImage)
+                    (*img==m_pano->getOptions().optimizeReferenceImage || m_pano->getImage(*img).YawisLinkedWith(m_pano->getImage(m_pano->getOptions().optimizeReferenceImage))))
                 {
                     optVec[*img].erase(*it);
                     continue;
                 };
-                if((*it=="Eev" || *it=="Er" || *it=="Eb") && *img==m_pano->getOptions().colorReferenceImage)
+                if(*it=="Eev" && (*img==m_pano->getOptions().colorReferenceImage || m_pano->getImage(*img).ExposureValueisLinkedWith(m_pano->getImage(m_pano->getOptions().colorReferenceImage))))
+                {
+                    optVec[*img].erase(*it);
+                    continue;
+                };
+                if (*it == "Er" && (*img == m_pano->getOptions().colorReferenceImage || m_pano->getImage(*img).WhiteBalanceRedisLinkedWith(m_pano->getImage(m_pano->getOptions().colorReferenceImage))))
+                {
+                    optVec[*img].erase(*it);
+                    continue;
+                };
+                if (*it == "Eb" && (*img == m_pano->getOptions().colorReferenceImage || m_pano->getImage(*img).WhiteBalanceBlueisLinkedWith(m_pano->getImage(m_pano->getOptions().colorReferenceImage))))
                 {
                     optVec[*img].erase(*it);
                     continue;
@@ -1990,7 +1960,7 @@ void ImagesTreeCtrl::OnChar(wxTreeEvent &e)
         case WXK_DELETE:
             {
                 HuginBase::UIntSet imgs=GetSelectedImages();
-                if(imgs.size()>0)
+                if(!imgs.empty())
                 {
                     PanoCommand::GlobalCmdHist::getInstance().addCommand(
                         new PanoCommand::RemoveImagesCmd(*m_pano, imgs)
