@@ -26,9 +26,9 @@
  *
  */
 
-#include <config.h>
-#include "hugin_utils/utils.h"
+#include "hugin_config.h"
 #include "panoinc_WX.h"
+#include "base_wx/wxutils.h"
 
 #include "hugin/LocalizedFileTipProvider.h"
 
@@ -71,12 +71,6 @@ wxString LocalizedFileTipProvider::GetTip()
         // Read the tip, and increment the current tip counter.
         tip = m_textfile.GetLine(m_currentTip++);
 
-#if !wxCHECK_VERSION(3,0,0)
-        // Allow a derived class's overrided virtual to modify the tip
-        // now if so desired.
-        tip = PreprocessTip(tip);
-#endif
-
         // Break if tip isn't a comment, and isn't an empty string
         // (or only stray space characters).
         if ( !tip.StartsWith(wxT("#")) && (tip.Trim() != wxEmptyString) )
