@@ -1154,7 +1154,11 @@ void MainFrame::LoadProjectFile(const wxString & filename)
     if ( !(preview_frame->IsIconized() ||(! preview_frame->IsShown()) ) ) {
         wxCommandEvent dummy;
         preview_frame->OnUpdate(dummy);
-    }
+    };
+    if (gl_preview_frame)
+    {
+        gl_preview_frame->ResetPreviewZoom();
+    };
 }
 
 #ifdef __WXMAC__
@@ -1241,6 +1245,10 @@ void MainFrame::OnNewProject(wxCommandEvent & e)
 
     wxCommandEvent dummy;
     preview_frame->OnUpdate(dummy);
+    if (gl_preview_frame)
+    {
+        gl_preview_frame->ResetPreviewZoom();
+    };
 }
 
 void MainFrame::OnAddImages( wxCommandEvent& event )
@@ -1990,7 +1998,7 @@ void MainFrame::ShowCtrlPointEditor(unsigned int img1, unsigned int img2)
     cpe->setRightImage(img2);
 }
 
-void MainFrame::ShowMaskEditor(size_t imgNr)
+void MainFrame::ShowMaskEditor(size_t imgNr, bool switchToCropMode)
 {
     if(!IsShown())
     {
@@ -1999,6 +2007,10 @@ void MainFrame::ShowMaskEditor(size_t imgNr)
     };
     m_notebook->SetSelection(1);
     mask_panel->setImage(imgNr, true);
+    if (switchToCropMode)
+    {
+        mask_panel->SwitchToCropMode();
+    };
 };
 
 void MainFrame::ShowStitcherTab()
