@@ -164,7 +164,7 @@ public:
     /** opens the control points tab with the both images selected */
     void ShowCtrlPointEditor(unsigned int img1, unsigned int img2);
     /** opens the mask/crop editor with the given image selected */
-    void ShowMaskEditor(size_t imgNr);
+    void ShowMaskEditor(size_t imgNr, bool switchToCropMode = false);
     /** opens the stitcher tab */
     void ShowStitcherTab();
 
