@@ -55,11 +55,15 @@ public:
     /** run the optimizer */
     void OnOptimizeButton(wxCommandEvent & e);
     void SetGuiLevel(GuiLevel newGuiLevel);
+    /** for external setting of "only active image" checkbox */
+    void SetOnlyActiveImages(const bool onlyActive);
 
 protected:
 
     void OnClose(wxCloseEvent& e);
     void OnReset(wxCommandEvent& e);
+    /** handle "only active images" checkbox */
+    void OnCheckOnlyActiveImages(wxCommandEvent &e);
 
     void runOptimizer(const HuginBase::UIntSet & img);
 
@@ -86,4 +90,4 @@ public:
     virtual bool CanHandle(wxXmlNode *node);
 };
 
-#endif // _WXPANOCOMMAND_H
+#endif // _OPTIMIZE_PHOTO_PANEL_H
