@@ -669,6 +669,8 @@ void PreferencesDialog::UpdateDisplayData(int panel)
         // Assistant settings
         t = cfg->Read(wxT("/Assistant/autoAlign"), HUGIN_ASS_AUTO_ALIGN) == 1;
         MY_BOOL_VAL("prefs_ass_autoAlign", t);
+        t = cfg->Read(wxT("/General/IgnoreFovRectilinearOnAdd"), 1l) == 1l;
+        MY_BOOL_VAL("prefs_ass_loadFovRectilinear", !t);
         MY_SPIN_VAL("prefs_ass_nControlPoints",
                     cfg->Read(wxT("/Assistant/nControlPoints"), HUGIN_ASS_NCONTROLPOINTS));
         double factor = HUGIN_ASS_PANO_DOWNSIZE_FACTOR;
@@ -835,6 +837,8 @@ void PreferencesDialog::UpdateDisplayData(int panel)
         MY_BOOL_VAL("prefs_warning_save", t);
         t = cfg->Read(wxT("/ShowExposureWarning"), 1l) == 1;
         MY_BOOL_VAL("prefs_warning_exposure", t);
+        t = cfg->Read(wxT("/ShowFisheyeCropHint"), 1l) == 1;
+        MY_BOOL_VAL("prefs_warning_fisheye_crop", t);
         MY_CHOICE_VAL("pref_editcp_action", cfg->Read(wxT("/EditCPAfterAction"), 0l));
     }
 }
@@ -884,6 +888,7 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent& e)
         if (noteb->GetSelection() == 2)
         {
             cfg->Write(wxT("/Assistant/autoAlign"), HUGIN_ASS_AUTO_ALIGN);
+            cfg->Write(wxT("/General/IgnoreFovRectilinearOnAdd"), 1l);
             cfg->Write(wxT("/Assistant/nControlPoints"), HUGIN_ASS_NCONTROLPOINTS);
             cfg->Write(wxT("/Assistant/panoDownsizeFactor"),HUGIN_ASS_PANO_DOWNSIZE_FACTOR);
             cfg->Write(wxT("/Assistant/Linefind"), HUGIN_ASS_LINEFIND);
@@ -960,6 +965,7 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent& e)
             cfg->Write(wxT("/OptimizePhotometric/nRandomPointsPerImage"), HUGIN_PHOTOMETRIC_OPTIMIZER_NRPOINTS);
             cfg->Write(wxT("/ShowSaveMessage"), 1l);
             cfg->Write(wxT("/ShowExposureWarning"), 1l);
+            cfg->Write(wxT("/ShowFisheyeCropHint"), 1l);
             cfg->Write(wxT("/EditCPAfterAction"), 0l);
         }
 
@@ -980,6 +986,7 @@ void PreferencesDialog::UpdateConfigData()
     wxConfigBase* cfg = wxConfigBase::Get();
     // Assistant
     cfg->Write(wxT("/Assistant/autoAlign"),MY_G_BOOL_VAL("prefs_ass_autoAlign"));
+    cfg->Write(wxT("/General/IgnoreFovRectilinearOnAdd"), !MY_G_BOOL_VAL("prefs_ass_loadFovRectilinear"));
     cfg->Write(wxT("/Assistant/nControlPoints"), MY_G_SPIN_VAL("prefs_ass_nControlPoints"));
     cfg->Write(wxT("/Assistant/panoDownsizeFactor"), MY_G_SPIN_VAL("prefs_ass_panoDownsizeFactor") / 100.0);
     cfg->Write(wxT("/Assistant/Linefind"), MY_G_BOOL_VAL("prefs_ass_linefind"));
@@ -1112,6 +1119,7 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Write(wxT("/OptimizePhotometric/nRandomPointsPerImage"), MY_G_SPIN_VAL("prefs_photo_optimizer_nr_points"));
     cfg->Write(wxT("/ShowSaveMessage"), MY_G_BOOL_VAL("prefs_warning_save"));
     cfg->Write(wxT("/ShowExposureWarning"), MY_G_BOOL_VAL("prefs_warning_exposure"));
+    cfg->Write(wxT("/ShowFisheyeCropHint"), MY_G_BOOL_VAL("prefs_warning_fisheye_crop"));
     cfg->Write(wxT("/EditCPAfterAction"), MY_G_CHOICE_VAL("pref_editcp_action"));
 
     cfg->Flush();
