@@ -24,14 +24,7 @@
  *
  */
 
-// use toggle buttons or uncomment check boxes
-
-//#ifndef __WXMAC__
-#define USE_TOGGLE_BUTTON 1
-//#endif
-//wxMac now has toggle buttons.
-
-#include <config.h>
+#include "hugin_config.h"
 
 #include "panoinc_WX.h"
 
@@ -56,8 +49,6 @@ extern "C" {
 #include <pano13/queryfeature.h>
 }
 
-using namespace hugin_utils;
-
 // a random id, hope this doesn't break something..
 enum {
     ID_PROJECTION_CHOICE = wxID_HIGHEST +1,
@@ -67,6 +58,8 @@ enum {
     ID_EXPOSURE_TEXT,
     ID_EXPOSURE_SPIN,
     ID_EXPOSURE_DEFAULT,
+    ID_RANGE_COMPRESSION_TEXT,
+    ID_RANGE_COMPRESSION_SPIN,
     ID_TOGGLE_BUT = wxID_HIGHEST+100,
     PROJ_PARAM_NAMES_ID = wxID_HIGHEST+1000,
     PROJ_PARAM_VAL_ID = wxID_HIGHEST+1100,
@@ -93,25 +86,13 @@ BEGIN_EVENT_TABLE(PreviewFrame, wxFrame)
     EVT_BUTTON(ID_EXPOSURE_DEFAULT, PreviewFrame::OnDefaultExposure)
     EVT_SPIN_DOWN(ID_EXPOSURE_SPIN, PreviewFrame::OnDecreaseExposure)
     EVT_SPIN_UP(ID_EXPOSURE_SPIN, PreviewFrame::OnIncreaseExposure)
+    EVT_SPIN_DOWN(ID_RANGE_COMPRESSION_SPIN, PreviewFrame::OnRangeCompressionDecrease)
+    EVT_SPIN_UP(ID_RANGE_COMPRESSION_SPIN, PreviewFrame::OnRangeCompressionIncrease)
     EVT_CHOICE(ID_BLEND_CHOICE, PreviewFrame::OnBlendChoice)
     EVT_CHOICE(ID_PROJECTION_CHOICE, PreviewFrame::OnProjectionChoice)
     EVT_CHOICE(ID_OUTPUTMODE_CHOICE, PreviewFrame::OnOutputChoice)
-#ifdef USE_TOGGLE_BUTTON
     EVT_TOGGLEBUTTON(-1, PreviewFrame::OnChangeDisplayedImgs)
-#else
-    EVT_CHECKBOX(-1, PreviewFrame::OnChangeDisplayedImgs)
-#endif
-#ifndef __WXMAC__
 	EVT_SCROLL_CHANGED(PreviewFrame::OnChangeFOV)
-#else
- #if wxCHECK_VERSION(2,9,0)
-	EVT_SCROLL_CHANGED(PreviewFrame::OnChangeFOV)
- #else
-	EVT_SCROLL_THUMBRELEASE(PreviewFrame::OnChangeFOV)
-	EVT_SCROLL_ENDSCROLL(PreviewFrame::OnChangeFOV)
-	EVT_SCROLL_THUMBTRACK(PreviewFrame::OnChangeFOV)
- #endif
-#endif
 	EVT_TOOL(ID_FULL_SCREEN, PreviewFrame::OnFullScreen)
     EVT_TOOL(ID_UNDO, PreviewFrame::OnUndo)
     EVT_TOOL(ID_REDO, PreviewFrame::OnRedo)
@@ -176,11 +157,7 @@ PreviewFrame::PreviewFrame(wxFrame * frame, HuginBase::Panorama &pano)
                                 _("VFOV"));
     m_VFOVSlider->SetLineSize(2);
     m_VFOVSlider->SetPageSize(10);
-#if wxCHECK_VERSION(3,0,1)
     m_VFOVSlider->SetTickFreq(5);
-#else
-    m_VFOVSlider->SetTickFreq(5,0);
-#endif
     m_VFOVSlider->SetToolTip(_("drag to change the vertical field of view"));
 
     flexSizer->Add(m_VFOVSlider, 0, wxEXPAND);
@@ -193,11 +170,7 @@ PreviewFrame::PreviewFrame(wxFrame * frame, HuginBase::Panorama &pano)
                                 _("HFOV"));
     m_HFOVSlider->SetPageSize(10);
     m_HFOVSlider->SetLineSize(2);
-#if wxCHECK_VERSION(3,0,1)
     m_HFOVSlider->SetTickFreq(5);
-#else
-    m_HFOVSlider->SetTickFreq(5,0);
-#endif
 
     m_HFOVSlider->SetToolTip(_("drag to change the horizontal field of view"));
 
@@ -295,7 +268,7 @@ PreviewFrame::PreviewFrame(wxFrame * frame, HuginBase::Panorama &pano)
                                         wxDefaultPosition,wxSize(50,-1), wxTE_PROCESS_ENTER);
     blendModeSizer->Add(m_exposureTextCtrl,
                           0,        // not vertically strechable
-                          wxLEFT | wxTOP | wxBOTTOM  | wxEXPAND | wxALIGN_CENTER_VERTICAL, // draw border all around
+                          wxLEFT | wxTOP | wxBOTTOM  | wxALIGN_CENTER_VERTICAL, // draw border all around
                           5);       // border width
 //    m_incExposureBut = new wxBitmapButton(this, ID_EXPOSURE_INCREASE,
 //                                          wxArtProvider::GetBitmap(wxART_GO_FORWARD));
@@ -303,8 +276,17 @@ PreviewFrame::PreviewFrame(wxFrame * frame, HuginBase::Panorama &pano)
                                          wxDefaultSize, wxSP_VERTICAL);
     m_exposureSpinBut->SetRange(-0x8000, 0x7fff);
     m_exposureSpinBut->SetValue(0);
+    m_exposureSpinBut->SetMaxSize(wxSize(-1, m_exposureTextCtrl->GetSize().GetHeight()));
     blendModeSizer->Add(m_exposureSpinBut, 0, wxALIGN_CENTER_VERTICAL);
-
+    blendModeSizer->Add(new wxStaticText(this, wxID_ANY, _("Range compression:")), 0, wxALIGN_CENTER_VERTICAL | wxLEFT | wxRIGHT, 5);
+    m_rangeCompressionTextCtrl = new wxTextCtrl(this, ID_RANGE_COMPRESSION_TEXT, wxT("0"),
+        wxDefaultPosition, wxSize(30, -1), wxTE_PROCESS_ENTER);
+    blendModeSizer->Add(m_rangeCompressionTextCtrl, 0, wxLEFT | wxTOP | wxBOTTOM | wxALIGN_CENTER_VERTICAL, 5);
+    m_rangeCompressionSpinBut = new wxSpinButton(this, ID_RANGE_COMPRESSION_SPIN, wxDefaultPosition, wxDefaultSize, wxSP_VERTICAL);
+    m_rangeCompressionSpinBut->SetRange(-0x8000, 0x7fff);
+    m_rangeCompressionSpinBut->SetValue(0);
+    m_rangeCompressionSpinBut->SetMaxSize(wxSize(-1, m_rangeCompressionTextCtrl->GetSize().GetHeight()));
+    blendModeSizer->Add(m_rangeCompressionSpinBut, 0, wxALIGN_CENTER_VERTICAL);
     m_topsizer->Add(blendModeSizer, 0, wxEXPAND | wxALL, 5);
 
     m_projParamSizer = new wxStaticBoxSizer(
@@ -332,13 +314,13 @@ PreviewFrame::PreviewFrame(wxFrame * frame, HuginBase::Panorama &pano)
         m_projParamTextCtrl[i]->PushEventHandler(new TextKillFocusHandler(this));
         m_projParamSizer->Add(m_projParamTextCtrl[i],
                         0,        // not vertically strechable
-                        wxALL | wxEXPAND | wxALIGN_CENTER_VERTICAL, // draw border all around
+                        wxALL | wxALIGN_CENTER_VERTICAL, // draw border all around
                         5);       // border width
 
         m_projParamSlider[i] = new wxSlider(this, PROJ_PARAM_SLIDER_ID+i, 0, -90, 90);
         m_projParamSizer->Add(m_projParamSlider[i],
                         1,        // not vertically strechable
-                        wxALL | wxALIGN_CENTER_VERTICAL | wxEXPAND, // draw border all around
+                        wxALL | wxALIGN_CENTER_VERTICAL, // draw border all around
                         5);       // border width
     }
 
@@ -409,7 +391,6 @@ PreviewFrame::~PreviewFrame()
 {
     DEBUG_TRACE("dtor writing config");
     wxConfigBase * config = wxConfigBase::Get();
-    wxSize sz = GetClientSize();
 
     StoreFramePosition(this, wxT("PreviewFrame"));
 
@@ -434,7 +415,7 @@ void PreviewFrame::OnChangeDisplayedImgs(wxCommandEvent & e)
 {
     int id = e.GetId() - ID_TOGGLE_BUT;
     int nImg = m_pano.getNrOfImages();
-    UIntSet activeImages = m_pano.getActiveImages();
+    HuginBase::UIntSet activeImages = m_pano.getActiveImages();
     DEBUG_DEBUG("toggle_button_id: " << id << " nImg:" << nImg << "  m_ToggleButtons.size(): " << m_ToggleButtons.size());
     if (id >= 0 && id < nImg) {
         if (e.IsChecked()) {
@@ -451,7 +432,7 @@ void PreviewFrame::OnChangeDisplayedImgs(wxCommandEvent & e)
     }
 }
 
-void PreviewFrame::panoramaChanged(Panorama &pano)
+void PreviewFrame::panoramaChanged(HuginBase::Panorama &pano)
 {
     const HuginBase::PanoramaOptions & opts = pano.getOptions();
 
@@ -475,9 +456,10 @@ void PreviewFrame::panoramaChanged(Panorama &pano)
         m_incExposureBut->Show();
         */
     }
-    m_exposureTextCtrl->SetValue(wxString(doubleToString(opts.outputExposureValue,2).c_str(), wxConvLocal));
+    m_exposureTextCtrl->SetValue(wxString(hugin_utils::doubleToString(opts.outputExposureValue,2).c_str(), wxConvLocal));
+    m_rangeCompressionTextCtrl->SetValue(wxString(hugin_utils::doubleToString(opts.outputRangeCompression,1).c_str(), wxConvLocal));
 
-    bool activeImgs = pano.getActiveImages().size() > 0;
+    const bool activeImgs = !pano.getActiveImages().empty();
     m_ToolBar->EnableTool(XRCID("preview_center_tool"), activeImgs);
     m_ToolBar->EnableTool(XRCID("preview_fit_pano_tool"), activeImgs);
     m_ToolBar->EnableTool(XRCID("preview_update_tool"), activeImgs);
@@ -499,7 +481,7 @@ void PreviewFrame::panoramaChanged(Panorama &pano)
                 wxString str2(pp->name, wxConvLocal);
                 str2 = wxGetTranslation(str2);
                 m_projParamNamesLabel[i]->SetLabel(str2);
-                m_projParamSlider[i]->SetRange(roundi(pp->minValue), roundi(pp->maxValue));
+                m_projParamSlider[i]->SetRange(hugin_utils::roundi(pp->minValue), hugin_utils::roundi(pp->maxValue));
             }
             for(;i < PANO_PROJECTION_MAX_PARMS; i++) {
                 m_projParamNamesLabel[i]->Hide();
@@ -517,9 +499,9 @@ void PreviewFrame::panoramaChanged(Panorama &pano)
         std::vector<double> params = opts.getProjectionParameters();
         assert((int) params.size() == nParam);
         for (int i=0; i < nParam; i++) {
-            wxString val = wxString(doubleToString(params[i],1).c_str(), wxConvLocal);
+            wxString val = wxString(hugin_utils::doubleToString(params[i],1).c_str(), wxConvLocal);
             m_projParamTextCtrl[i]->SetValue(wxString(val.wc_str(), wxConvLocal));
-            m_projParamSlider[i]->SetValue(roundi(params[i]));
+            m_projParamSlider[i]->SetValue(hugin_utils::roundi(params[i]));
         }
     }
     if (relayout) {
@@ -528,14 +510,14 @@ void PreviewFrame::panoramaChanged(Panorama &pano)
     }
     SetStatusText(_("Center panorama with left mouse button, set horizon with right button"),0);
     SetStatusText(wxString::Format(wxT("%.1f x %.1f"), opts.getHFOV(), opts.getVFOV()),2);
-    m_HFOVSlider->SetValue(roundi(opts.getHFOV()));
-    m_VFOVSlider->SetValue(roundi(opts.getVFOV()));
+    m_HFOVSlider->SetValue(hugin_utils::roundi(opts.getHFOV()));
+    m_VFOVSlider->SetValue(hugin_utils::roundi(opts.getVFOV()));
 
     m_oldProjFormat = opts.getProjection();
     updatePano();
 }
 
-void PreviewFrame::panoramaImagesChanged(Panorama &pano, const UIntSet &changed)
+void PreviewFrame::panoramaImagesChanged(HuginBase::Panorama &pano, const HuginBase::UIntSet &changed)
 {
     DEBUG_TRACE("");
 
@@ -557,22 +539,15 @@ void PreviewFrame::panoramaImagesChanged(Panorama &pano, const UIntSet &changed)
 
     // add buttons
     if ( nrImages >= nrButtons ) {
-        for(UIntSet::const_iterator it = changed.begin(); it != changed.end(); ++it){
+        for(HuginBase::UIntSet::const_iterator it = changed.begin(); it != changed.end(); ++it){
             if (*it >= nrButtons) {
-                unsigned int imgNr = *it;
                 // create new item.
 //                wxImage * bmp = new wxImage(sz.GetWidth(), sz.GetHeight());
-#ifdef USE_TOGGLE_BUTTON
                 wxToggleButton * but = new wxToggleButton(m_ButtonPanel,
                                                           ID_TOGGLE_BUT + *it,
                                                           wxString::Format(wxT("%d"),*it),
                                                           wxDefaultPosition, wxDefaultSize,
                                                           wxBU_EXACTFIT);
-#else
-                wxCheckBox * but = new wxCheckBox(m_ButtonPanel,
-                                                  ID_TOGGLE_BUT + *it,
-                                                  wxString::Format(wxT("%d"),*it));
-#endif
                 wxSize sz = but->GetSize();
 //                but->SetSize(res.GetWidth(),sz.GetHeight());
                 // HACK.. set fixed width. that should work
@@ -591,7 +566,7 @@ void PreviewFrame::panoramaImagesChanged(Panorama &pano, const UIntSet &changed)
     }
 
     // update existing items
-    UIntSet displayedImages = m_pano.getActiveImages();
+    HuginBase::UIntSet displayedImages = m_pano.getActiveImages();
     for (unsigned i=0; i < nrImages; i++) {
         m_ToggleButtons[i]->SetValue(set_contains(displayedImages, i));
         wxFileName tFilename(wxString (pano.getImage(i).getFilename().c_str(), HUGIN_CONV_FILENAME));
@@ -599,11 +574,7 @@ void PreviewFrame::panoramaImagesChanged(Panorama &pano, const UIntSet &changed)
     }
 
     if (dirty) {
-#if wxCHECK_VERSION(3,0,0)
         m_ButtonSizer->FitInside(m_ButtonPanel);
-#else
-		m_ButtonSizer->SetVirtualSizeHints(m_ButtonPanel);
-#endif
 		// Layout();
 		DEBUG_INFO("New m_ButtonPanel width: " << (m_ButtonPanel->GetSize()).GetWidth());
 		DEBUG_INFO("New m_ButtonPanel Height: " << (m_ButtonPanel->GetSize()).GetHeight());
@@ -658,7 +629,7 @@ void PreviewFrame::OnProjectionChanged()
 
 void PreviewFrame::OnCenterHorizontally(wxCommandEvent & e)
 {
-    if (m_pano.getActiveImages().size() == 0) return;
+    if (m_pano.getActiveImages().empty()) return;
 
     PanoCommand::GlobalCmdHist::getInstance().addCommand(
         new PanoCommand::CenterPanoCmd(m_pano)
@@ -688,14 +659,14 @@ void PreviewFrame::updatePano()
 
 void PreviewFrame::OnFitPano(wxCommandEvent & e)
 {
-    if (m_pano.getActiveImages().size() == 0) return;
+    if (m_pano.getActiveImages().empty()) return;
 
     DEBUG_TRACE("");
     HuginBase::PanoramaOptions opt = m_pano.getOptions();
     HuginBase::CalculateFitPanorama fitPano(m_pano);
     fitPano.run();
     opt.setHFOV(fitPano.getResultHorizontalFOV());
-    opt.setHeight(roundi(fitPano.getResultHeight()));
+    opt.setHeight(hugin_utils::roundi(fitPano.getResultHeight()));
 
     PanoCommand::GlobalCmdHist::getInstance().addCommand(
         new PanoCommand::SetPanoOptionsCmd( m_pano, opt )
@@ -710,7 +681,7 @@ void PreviewFrame::OnShowAll(wxCommandEvent & e)
     if (m_pano.getNrOfImages() == 0) return;
 
     DEBUG_ASSERT(m_pano.getNrOfImages() == m_ToggleButtons.size());
-    UIntSet displayedImgs;
+    HuginBase::UIntSet displayedImgs;
     for (unsigned int i=0; i < m_pano.getNrOfImages(); i++) {
         displayedImgs.insert(i);
     }
@@ -728,7 +699,7 @@ void PreviewFrame::OnShowNone(wxCommandEvent & e)
     for (unsigned int i=0; i < m_pano.getNrOfImages(); i++) {
         m_ToggleButtons[i]->SetValue(false);
     }
-    UIntSet displayedImgs;
+    HuginBase::UIntSet displayedImgs;
     PanoCommand::GlobalCmdHist::getInstance().addCommand(
         new PanoCommand::SetActiveImagesCmd(m_pano, displayedImgs)
         );
@@ -745,19 +716,19 @@ void PreviewFrame::OnNumTransform(wxCommandEvent & e)
     if (dlg.ShowModal() == wxID_OK ) {
         wxString text = XRCCTRL(dlg, "numtrans_yaw", wxTextCtrl)->GetValue();
         double y;
-        if (!str2double(text, y)) {
+        if (!hugin_utils::str2double(text, y)) {
             wxLogError(_("Yaw value must be numeric."));
             return;
         }
         text = XRCCTRL(dlg, "numtrans_pitch", wxTextCtrl)->GetValue();
         double p;
-        if (!str2double(text, p)) {
+        if (!hugin_utils::str2double(text, p)) {
             wxLogError(_("Pitch value must be numeric."));
             return;
         }
         text = XRCCTRL(dlg, "numtrans_roll", wxTextCtrl)->GetValue();
         double r;
-        if (!str2double(text, r)) {
+        if (!hugin_utils::str2double(text, r)) {
             wxLogError(_("Roll value must be numeric."));
             return;
         }
@@ -780,31 +751,65 @@ void PreviewFrame::OnTextCtrlChanged(wxCommandEvent & e)
         DEBUG_INFO ("target exposure = " << text.mb_str(wxConvLocal) );
         double p = 0;
         if (text != wxT("")) {
-            if (!str2double(text, p)) {
+            if (!hugin_utils::str2double(text, p)) {
                 wxLogError(_("Value must be numeric."));
                 return;
             }
         }
         opts.outputExposureValue = p;
-    } else {
-        int nParam = opts.m_projFeatures.numberOfParameters;
-        std::vector<double> para = opts.getProjectionParameters();
-        for (int i = 0; i < nParam; i++) {
-            if (e.GetEventObject() == m_projParamTextCtrl[i]) {
-                wxString text = m_projParamTextCtrl[i]->GetValue();
-                DEBUG_INFO ("param " << i << ":  = " << text.mb_str(wxConvLocal) );
-                double p = 0;
-                if (text != wxT("")) {
-                    if (!str2double(text, p)) {
-                        wxLogError(_("Value must be numeric."));
-                        return;
-                    }
-                }
-                para[i] = p;
-            }
-        }
-        opts.setProjectionParameters(para);
     }
+    else
+    {
+        if (e.GetEventObject() == m_rangeCompressionTextCtrl)
+        {
+            //range compression
+            const wxString text = m_rangeCompressionTextCtrl->GetValue();
+            if (text.IsEmpty())
+            {
+                return;
+            };
+            double p = 0;
+            if (!hugin_utils::str2double(text, p))
+            {
+                wxLogError(_("Value must be numeric."));
+                return;
+            };
+            if (p < 0 || p>20)
+            {
+                wxLogError(_("Value for range compression is outside of valid range."));
+                return;
+            };
+            if (p == opts.outputRangeCompression)
+            {
+                return;
+            };
+            opts.outputRangeCompression = p;
+        }
+        else
+        {
+            int nParam = opts.m_projFeatures.numberOfParameters;
+            std::vector<double> para = opts.getProjectionParameters();
+            for (int i = 0; i < nParam; i++)
+            {
+                if (e.GetEventObject() == m_projParamTextCtrl[i])
+                {
+                    wxString text = m_projParamTextCtrl[i]->GetValue();
+                    DEBUG_INFO("param " << i << ":  = " << text.mb_str(wxConvLocal));
+                    double p = 0;
+                    if (text != wxT(""))
+                    {
+                        if (!hugin_utils::str2double(text, p))
+                        {
+                            wxLogError(_("Value must be numeric."));
+                            return;
+                        }
+                    }
+                    para[i] = p;
+                }
+            }
+            opts.setProjectionParameters(para);
+        };
+    };
     PanoCommand::GlobalCmdHist::getInstance().addCommand(
             new PanoCommand::SetPanoOptionsCmd( m_pano, opts )
                                            );
@@ -905,6 +910,26 @@ void PreviewFrame::OnDecreaseExposure( wxSpinEvent & e )
     updatePano();
 }
 
+void PreviewFrame::OnRangeCompressionIncrease(wxSpinEvent & e)
+{
+    HuginBase::PanoramaOptions opt = m_pano.getOptions();
+    opt.outputRangeCompression = std::min(opt.outputRangeCompression + 1.0, 20.0);
+    PanoCommand::GlobalCmdHist::getInstance().addCommand(
+        new PanoCommand::SetPanoOptionsCmd(m_pano, opt)
+    );
+    updatePano();
+}
+
+void PreviewFrame::OnRangeCompressionDecrease(wxSpinEvent & e)
+{
+    HuginBase::PanoramaOptions opt = m_pano.getOptions();
+    opt.outputRangeCompression = std::max(opt.outputRangeCompression - 1.0, 0.0);
+    PanoCommand::GlobalCmdHist::getInstance().addCommand(
+        new PanoCommand::SetPanoOptionsCmd(m_pano, opt)
+    );
+    updatePano();
+}
+
 void PreviewFrame::OnProjectionChoice( wxCommandEvent & e )
 {
     if (e.GetEventObject() == m_ProjectionChoice) {
