@@ -138,6 +138,11 @@ void PreviewPanel::panoramaChanged(HuginBase::Panorama &pano)
         DEBUG_DEBUG("output exposure value changed");
         dirty = true;
     };
+    if (newOpts.outputRangeCompression != opts.outputRangeCompression)
+    {
+        DEBUG_DEBUG("output range compression changed");
+        dirty = true;
+    };
 
     opts = newOpts;
     if (dirty) {
@@ -201,6 +206,26 @@ struct ExposureResponseFunctor2
     }
 };
 
+struct RangeCompression
+{
+public:
+    RangeCompression(double rangeCompression)
+    {
+        m_rangeCompression = rangeCompression;
+        m_logM1 = std::log2(m_rangeCompression + 1);
+    };
+
+    vigra::RGBValue<float> operator()(vigra::RGBValue<float> const& v) const
+    {
+        return vigra::RGBValue<float>(std::log2(m_rangeCompression * v.red() + 1) / m_logM1,
+            std::log2(m_rangeCompression * v.green() + 1) / m_logM1,
+            std::log2(m_rangeCompression * v.blue() + 1) / m_logM1
+            );
+    }
+private:
+    double m_rangeCompression;
+    double m_logM1;
+};
 
 void PreviewPanel::updatePreview()
 {
@@ -272,7 +297,7 @@ void PreviewPanel::updatePreview()
 
         DEBUG_DEBUG("about to stitch images, pano size: " << m_panoImgSize);
         HuginBase::UIntSet displayedImages = pano->getActiveImages();
-        if (displayedImages.size() > 0) {
+        if (!displayedImages.empty()) {
             if (opts.outputMode == HuginBase::PanoramaOptions::OUTPUT_HDR) {
                 DEBUG_DEBUG("HDR output merge");
 
@@ -348,14 +373,19 @@ void PreviewPanel::updatePreview()
                 // apply the exposure
                 double scale = 1.0/pow(2.0,opts.outputExposureValue);
 
-                vigra::transformImage(srcImageRange(panoImg), destImage(panoImg),
+                vigra::omp::transformImage(srcImageRange(panoImg), destImage(panoImg),
                                       vigra::functor::Arg1()*vigra::functor::Param(scale));
 
                 DEBUG_DEBUG("LDR output, with response: " << src.getResponseType());
                 if (src.getResponseType() == HuginBase::SrcPanoImage::RESPONSE_LINEAR) {
-                    vigra::transformImage(srcImageRange(panoImg), destImage(panoImg8),
+                    vigra::omp::transformImage(srcImageRange(panoImg), destImage(panoImg8),
                                           vigra::functor::Arg1()*vigra::functor::Param(255));
                 } else {
+                    if (opts.outputRangeCompression > 0.0)
+                    {
+                        RangeCompression rangeCompression(opts.outputRangeCompression);
+                        vigra::omp::transformImage(srcImageRange(panoImg), destImage(panoImg), rangeCompression);
+                    }
                 // create suitable lut for response
                     typedef  std::vector<double> LUT;
                     LUT lut;
@@ -378,7 +408,7 @@ void PreviewPanel::updatePreview()
                     typedef vigra::RGBValue<float> FRGB;
                     vigra_ext::LUTFunctor<FRGB, LUT> lutf(lut);
 
-                    vigra::transformImage(srcImageRange(panoImg), destImage(panoImg8),
+                    vigra::omp::transformImage(srcImageRange(panoImg), destImage(panoImg8),
                                           lutf);
                 }
                 // apply color profiles
