@@ -46,6 +46,7 @@
 #include "hugin/CPListFrame.h"
 #include "hugin/PreviewPanel.h"
 #include "hugin/GLPreviewFrame.h"
+#include "hugin/RawImport.h"
 #include "base_wx/PTWXDlg.h"
 #include "base_wx/CommandHistory.h"
 #include "base_wx/wxcms.h"
@@ -57,13 +58,16 @@
 #include "base_wx/platform.h"
 #include "base_wx/huginConfig.h"
 #include <wx/cshelp.h>
+#include <wx/stdpaths.h>
 #ifdef __WXMSW__
 #include <wx/dir.h>
-#include <wx/stdpaths.h>
 #if wxCHECK_VERSION(3,1,0)
 #include <wx/taskbarbutton.h>
 #endif
 #endif
+#if defined __WXGTK__ && wxCHECK_VERSION(3,1,1)
+#include "base_wx/wxPlatform.h"
+#endif
 
 #include <tiffio.h>
 
@@ -185,13 +189,21 @@ bool huginApp::OnInit()
 {
     DEBUG_TRACE("=========================== huginApp::OnInit() begin ===================");
     SetAppName(wxT("hugin"));
-    
+#if defined __WXGTK__ && wxCHECK_VERSION(3,1,1)
+    CheckConfigFilename();
+#endif
+
     // Connect to ImageCache: we need to tell it when it is safe to handle UI events.
     ImageCache::getInstance().asyncLoadCompleteSignal = &huginApp::imageLoadedAsync;
 
 #ifdef __WXMAC__
     // do not use the native list control on OSX (it is very slow with the control point list window)
     wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), 1);
+    // On OS X the file open does by default not show the file type list
+    // Apple means this is not necessary
+    // but the the add images dialog needs this selection, so force to 
+    // display always the file type list
+    wxSystemOptions::SetOption(wxOSX_FILEDIALOG_ALWAYS_SHOW_TYPES, 1);
 #endif
 
     // register our custom pano tools dialog handlers
@@ -244,7 +256,20 @@ bool huginApp::OnInit()
     }
 #endif
     
-	
+#elif defined UNIX_SELF_CONTAINED_BUNDLE
+    // initialize paths
+    {
+      wxFileName exePath(wxStandardPaths::Get().GetExecutablePath());
+      m_utilsBinDir = exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
+      exePath.RemoveLastDir();
+      const wxString huginRoot=exePath.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
+      m_xrcPrefix = huginRoot + wxT("share/hugin/xrc/");
+      m_DataDir = huginRoot + wxT("share/hugin/data/");
+
+      // locale setup
+      locale.AddCatalogLookupPathPrefix(huginRoot + wxT("share/locale"));
+    }
+
 #else
     // add the locale directory specified during configure
     m_xrcPrefix = wxT(INSTALL_XRC_DIR);
@@ -332,6 +357,7 @@ bool huginApp::OnInit()
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("lensdb_dialogs.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("image_variable_dlg.xrc"));
     wxXmlResource::Get()->Load(m_xrcPrefix + wxT("dlg_warning.xrc"));
+    wxXmlResource::Get()->Load(m_xrcPrefix + wxT("import_raw_dialog.xrc"));
 #endif
 
 #ifdef __WXMAC__
@@ -356,7 +382,7 @@ bool huginApp::OnInit()
     exeFile.SetName("PTBatcherGUI");
     wxTaskBarJumpListItem *item1 = new wxTaskBarJumpListItem(
         NULL, wxTASKBAR_JUMP_LIST_TASK, _("Open Batch Processor"), exeFile.GetFullPath(), wxEmptyString,
-        _("Opens PTBatcher, the batch processor for Hugin's project files"),
+        _("Opens PTBatcherGUI, the batch processor for Hugin's project files"),
         exeFile.GetFullPath(), 0);
     jumpList.GetTasks().Append(item1);
     exeFile.SetName("calibrate_lens_gui");
@@ -479,6 +505,7 @@ bool huginApp::OnInit()
             frame->LoadProjectFile(file.GetFullPath());
         } else {
             std::vector<std::string> filesv;
+            std::vector<std::string> rawFilesv;
             bool actualPathSet = false;
             for (int i=1; i< argc; i++) 
             {
@@ -500,45 +527,81 @@ bool huginApp::OnInit()
 #else
                 wxFileName file(argv[i]);
 #endif
-                if (file.GetExt().CmpNoCase(wxT("jpg")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("jpeg")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("tif")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("tiff")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("png")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("bmp")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("gif")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("pnm")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("sun")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("hdr")) == 0 ||
-                    file.GetExt().CmpNoCase(wxT("viff")) == 0 )
+                if (file.IsRelative())
                 {
-                    if(file.IsRelative())
-                        file.MakeAbsolute(cwd);
-                    if(!containsInvalidCharacters(file.GetFullPath()))
+                    file.MakeAbsolute(cwd);
+                };
+                if (IsRawExtension(file.GetExt()))
+                {
+                    // we got a raw file from command line
+                    if (!containsInvalidCharacters(file.GetFullPath()))
                     {
-                        filesv.push_back((const char *)(file.GetFullPath().mb_str(HUGIN_CONV_FILENAME)));
+                        rawFilesv.push_back((const char*)file.GetFullPath().mb_str(HUGIN_CONV_FILENAME));
+                        // Use the first filename to set actualPath.
+                        if (!actualPathSet)
+                        {
+                            config->Write(wxT("/actualPath"), file.GetPath());
+                            actualPathSet = true;
+                        };
                     };
-
-                    // Use the first filename to set actualPath.
-                    if (! actualPathSet)
-                    {
-                        config->Write(wxT("/actualPath"), file.GetPath());
-                        actualPathSet = true;
-                    }
                 }
+                else
+                {
+                    if (vigra::isImage(file.GetFullPath().mb_str(HUGIN_CONV_FILENAME)))
+                    {
+                        if (!containsInvalidCharacters(file.GetFullPath()))
+                        {
+                            filesv.push_back((const char *)(file.GetFullPath().mb_str(HUGIN_CONV_FILENAME)));
+                            // Use the first filename to set actualPath.
+                            if (!actualPathSet)
+                            {
+                                config->Write(wxT("/actualPath"), file.GetPath());
+                                actualPathSet = true;
+                            };
+                        };
+                    };
+                };
 #if defined __WXMSW__
                 } while (dir.GetNext(&foundFile));
 #endif
             }
-            if(filesv.size()>0)
+            if(!filesv.empty())
             {
                 std::vector<PanoCommand::PanoCommand*> cmds;
                 cmds.push_back(new PanoCommand::wxAddImagesCmd(pano,filesv));
                 cmds.push_back(new PanoCommand::DistributeImagesCmd(pano));
                 cmds.push_back(new PanoCommand::CenterPanoCmd(pano));
                 PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::CombinedPanoCommand(pano, cmds));
-            }
-        }
+            };
+            if (!rawFilesv.empty())
+            {
+                if (rawFilesv.size() == 1)
+                {
+                    wxMessageDialog message(GetTopWindow(), _("You selected only one raw file. This is not recommended.\nAll raw files should be converted at once."),
+#ifdef _WIN32
+                        _("Hugin"),
+#else
+                        wxT(""),
+#endif
+                        wxICON_EXCLAMATION | wxOK | wxCANCEL);
+                    message.SetOKLabel(_("Convert anyway."));
+                    if (message.ShowModal() != wxID_OK)
+                    {
+                        return true;
+                    };
+            };
+                RawImportDialog dlg(GetTopWindow(), &pano, rawFilesv);
+                // check that raw files are from same camera and that all can be read
+                if (dlg.CheckRawFiles())
+                {
+                    // now show dialog
+                    if (dlg.ShowModal() == wxID_OK)
+                    {
+                        PanoCommand::GlobalCmdHist::getInstance().addCommand(dlg.GetPanoCommand());
+                    };
+                };
+            };
+        };
     }
 #ifdef __WXMAC__
     m_macInitDone = true;
