@@ -33,6 +33,9 @@
 #include <panodata/Panorama.h>
 #include <base_wx/platform.h>
 #include "hugin/config_defaults.h"
+#if defined __WXGTK__ && wxCHECK_VERSION(3,1,1)
+#include "base_wx/wxPlatform.h"
+#endif
 
 extern "C"
 {
@@ -41,6 +44,9 @@ extern "C"
 
 void iCPApp::ReadDetectorConfig()
 {
+#if defined __WXGTK__ && wxCHECK_VERSION(3,1,1)
+    CheckConfigFilename();
+#endif
     wxConfig config(wxT("hugin"));
     //read cp detectors settings
     CPDetectorConfig cpdetector_config;
@@ -130,7 +136,7 @@ int iCPApp::OnRun()
     HuginBase::CPVector cps = matcher.automatch(m_cpsetting,pano,imgs,m_matches,NULL);
     PT_setProgressFcn(NULL);
     PT_setInfoDlgFcn(NULL);
-    if(cps.size()==0)
+    if(cps.empty())
     {
         return 1;
     };
