@@ -31,7 +31,9 @@
 #include "FailedProjectsDialog.h"
 #ifdef __WXMSW__
 #include <powrprof.h>
+#ifdef _MSC_VER
 #pragma comment(lib, "PowrProf.lib")
+#endif
 #if wxCHECK_VERSION(3,1,0)
 #include <wx/taskbarbutton.h>
 #endif
@@ -77,8 +79,7 @@ bool BatchDropTarget::OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& fil
 
 enum
 {
-    wxEVT_COMMAND_RELOAD_BATCH,
-    wxEVT_COMMAND_UPDATE_LISTBOX
+    EVT_TIMER_UPDATE_LISTBOX
 };
 
 BEGIN_EVENT_TABLE(BatchFrame, wxFrame)
@@ -119,8 +120,7 @@ BEGIN_EVENT_TABLE(BatchFrame, wxFrame)
     EVT_CHECKBOX(XRCID("cb_savelog"), BatchFrame::OnCheckSaveLog)
     EVT_END_PROCESS(-1, BatchFrame::OnProcessTerminate)
     EVT_CLOSE(BatchFrame::OnClose)
-    EVT_MENU(wxEVT_COMMAND_RELOAD_BATCH, BatchFrame::OnReloadBatch)
-    EVT_MENU(wxEVT_COMMAND_UPDATE_LISTBOX, BatchFrame::OnUpdateListBox)
+    EVT_TIMER(EVT_TIMER_UPDATE_LISTBOX, BatchFrame::OnUpdateListBox)
     EVT_COMMAND(wxID_ANY, EVT_BATCH_FAILED, BatchFrame::OnBatchFailed)
     EVT_COMMAND(wxID_ANY, EVT_INFORMATION, BatchFrame::OnBatchInformation)
     EVT_COMMAND(wxID_ANY, EVT_UPDATE_PARENT, BatchFrame::OnRefillListBox)
@@ -132,7 +132,6 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
 {
     this->SetLocaleAndXRC(locale,xrc);
     m_cancelled = false;
-    m_closeThread = false;
 
     //load xrc resources
     wxXmlResource::Get()->LoadFrame(this, (wxWindow* )NULL, wxT("batch_frame"));
@@ -182,16 +181,17 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
             wxYES_NO | wxICON_EXCLAMATION, NULL)==wxNO)
         {
             m_batch->LoadTemp();
+        }
+        else
+        {
+            // save empty batch queue
+            m_batch->SaveTemp();
         };
     }
     else
     {
         m_batch->LoadTemp();
     };
-    if(m_batch->GetLastFile().length()==0)
-    {
-        m_batch->SaveTemp();
-    }
     projListBox = XRCCTRL(*this,"project_listbox",ProjectListBox);
     // fill at end list box, check which options are available
     m_endChoice = XRCCTRL(*this, "choice_end", wxChoice);
@@ -217,8 +217,6 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
     };
 #endif
 
-    this->wxThreadHelper::CreateThread();
-    this->GetThread()->Run();
     //TO-DO: include a batch or project progress gauge?
     projListBox->Fill(m_batch);
     SetDropTarget(new BatchDropTarget());
@@ -242,34 +240,9 @@ BatchFrame::BatchFrame(wxLocale* locale, wxString xrc)
     // check settings of help window and fix when needed
     FixHelpSettings();
 #endif
-}
-
-void* BatchFrame::Entry()
-{
-    //we constantly poll the working dir for new files and wait a bit on each loop
-    while(!m_closeThread)
-    {
-        //don't access GUI directly in this function (function is running as separate thread)
-        //check, if ptbt file was changed
-        wxFileName aFile(m_batch->GetLastFile());
-        if(!aFile.FileExists())
-        {
-            wxQueueEvent(this, new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, wxEVT_COMMAND_RELOAD_BATCH));
-        }
-        else
-        {
-            wxDateTime create;
-            aFile.GetTimes(NULL,NULL,&create);
-            if(create.IsLaterThan(m_batch->GetLastFileDate()))
-            {
-                wxQueueEvent(this, new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, wxEVT_COMMAND_RELOAD_BATCH));
-            };
-        };
-        //update project list box
-        wxQueueEvent(this, new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED, wxEVT_COMMAND_UPDATE_LISTBOX));
-        GetThread()->Sleep(1000);
-    }
-    return 0;
+    m_updateProjectsTimer = new wxTimer(this, EVT_TIMER_UPDATE_LISTBOX);
+    // start timer for check for updates in project files
+    m_updateProjectsTimer->StartOnce(5000);
 }
 
 wxStatusBar* BatchFrame::OnCreateStatusBar(int number, long style, wxWindowID id, const wxString& name)
@@ -289,7 +262,7 @@ bool BatchFrame::IsPaused()
     return m_batch->IsPaused();
 };
 
-void BatchFrame::OnUpdateListBox(wxCommandEvent& event)
+void BatchFrame::OnUpdateListBox(wxTimerEvent& event)
 {
     wxFileName tempFile;
     bool change = false;
@@ -340,16 +313,9 @@ void BatchFrame::OnUpdateListBox(wxCommandEvent& event)
     if(change)
     {
         m_batch->SaveTemp();
-    }
-};
-
-void BatchFrame::OnReloadBatch(wxCommandEvent& event)
-{
-    m_batch->ClearBatch();
-    m_batch->LoadTemp();
-    projListBox->DeleteAllItems();
-    projListBox->Fill(m_batch);
-    SetStatusText(wxT(""));
+    };
+    // start timer again
+    m_updateProjectsTimer->StartOnce(2000);
 };
 
 void BatchFrame::OnUserExit(wxCommandEvent& event)
@@ -472,7 +438,6 @@ void BatchFrame::AddDirToList(wxString aDir)
 
 void BatchFrame::AddToList(wxString aFile,Project::Target target)
 {
-    wxFileName name(aFile);
     m_batch->AddProjectToBatch(aFile,wxT(""),target);
     wxString s;
     switch(target)
@@ -511,7 +476,7 @@ void BatchFrame::OnButtonChangePrefix(wxCommandEvent& event)
         if (project->target == Project::STITCHING)
         {
             wxFileName prefix(project->prefix);
-            wxFileDialog dlg(0,_("Specify output prefix for project ")+project->path,
+            wxFileDialog dlg(0, wxString::Format(_("Specify output prefix for project %s"), project->path),
                              prefix.GetPath(),
                              prefix.GetFullName(), wxT(""),
                              wxFD_SAVE, wxDefaultPosition);
@@ -1041,36 +1006,42 @@ bool BatchFrame::GetCheckSaveLog()
 
 void BatchFrame::OnCheckOverwrite(wxCommandEvent& event)
 {
+    wxConfigBase* config=wxConfigBase::Get();
     if(event.IsChecked())
     {
         m_batch->overwrite = true;
-        wxConfigBase::Get()->Write(wxT("/BatchFrame/OverwriteCheck"), 1l);
+        config->Write(wxT("/BatchFrame/OverwriteCheck"), 1l);
     }
     else
     {
         m_batch->overwrite = false;
-        wxConfigBase::Get()->Write(wxT("/BatchFrame/OverwriteCheck"), 0l);
+        config->Write(wxT("/BatchFrame/OverwriteCheck"), 0l);
     }
+    config->Flush();
 }
 
 void BatchFrame::OnChoiceEnd(wxCommandEvent& event)
 {
     m_batch->atEnd = static_cast<Batch::EndTask>((size_t)m_endChoice->GetClientData(event.GetSelection()));
-    wxConfigBase::Get()->Write(wxT("/BatchFrame/AtEnd"), static_cast<long>(m_batch->atEnd));
+    wxConfigBase* config=wxConfigBase::Get();
+    config->Write(wxT("/BatchFrame/AtEnd"), static_cast<long>(m_batch->atEnd));
+    config->Flush();
 }
 
 void BatchFrame::OnCheckVerbose(wxCommandEvent& event)
 {
+    wxConfigBase* config=wxConfigBase::Get();
     if(event.IsChecked())
     {
         m_batch->verbose = true;
-        wxConfigBase::Get()->Write(wxT("/BatchFrame/VerboseCheck"), 1l);
+        config->Write(wxT("/BatchFrame/VerboseCheck"), 1l);
     }
     else
     {
         m_batch->verbose = false;
-        wxConfigBase::Get()->Write(wxT("/BatchFrame/VerboseCheck"), 0l);
-    }
+        config->Write(wxT("/BatchFrame/VerboseCheck"), 0l);
+    };
+    config->Flush();
     m_batch->ShowOutput(m_batch->verbose);
 }
 
@@ -1165,16 +1136,12 @@ void BatchFrame::OnClose(wxCloseEvent& event)
         };
     }
     config->Flush();
-    m_closeThread = true;
-    if (this->GetThread() && this->GetThread()->IsRunning())
-    {
-        this->GetThread()->Wait();
-    };
     if(m_tray!=NULL)
     {
         delete m_tray;
         m_tray = NULL;
     }
+    delete m_updateProjectsTimer;
     this->Destroy();
 }
 
@@ -1395,7 +1362,9 @@ void BatchFrame::OnRefillListBox(wxCommandEvent& event)
 void BatchFrame::OnMinimizeTrayMenu(wxCommandEvent& event)
 {
     UpdateTrayIcon(event.IsChecked());
-    wxConfigBase::Get()->Write(wxT("/BatchFrame/minimizeTray"), event.IsChecked());
+    wxConfigBase* config=wxConfigBase::Get();
+    config->Write(wxT("/BatchFrame/minimizeTray"), event.IsChecked());
+    config->Flush();
 }
 
 void BatchFrame::UpdateTrayIcon(const bool createTrayIcon)
