@@ -25,11 +25,10 @@
 
 #include "CenterHorizontally.h"
 
-#include <vigra/impex.hxx>
 #include <vigra/copyimage.hxx>
 #include <panodata/PanoramaData.h>
 #include <nona/RemappedPanoImage.h>
-
+#include <algorithms/basic/RotatePanorama.h>
 
 
 namespace HuginBase {
@@ -51,9 +50,10 @@ void CenterHorizontally::centerHorizontically(PanoramaData& panorama)
     Nona::RemappedPanoImage<vigra::BImage, vigra::BImage> remapped;
     
     // use selected images.
-    UIntSet allActiveImgs = panorama.getActiveImages();
+    const UIntSet allActiveImgs(panorama.getActiveImages());
 
-    if (allActiveImgs.size() == 0) {
+    if (allActiveImgs.empty())
+    {
         // do nothing if there are no images
         return;
     }
@@ -75,21 +75,12 @@ void CenterHorizontally::centerHorizontically(PanoramaData& panorama)
                 };
             };
         };
-        if(img.getX()!=0 || img.getY()!=0 || img.getZ()!=0)
-        {
-            //if translation parameters are non-zero break, 
-            //because centering by modifying yaw does not work in this case
-            return;
-        };
         if(consider)
             activeImgs.insert(*it);
     };
 
-    for (UIntSet::iterator it = activeImgs.begin(); it != activeImgs.end(); ++it) {
-        //    for (unsigned int imgNr=0; imgNr < getNrOfImages(); imgNr++) {
-        //        const PanoImage & img = getImage(*it);
-        //        Size2D sz(img.getWidth(), img.getHeight());
-        //        remapped.setPanoImage(*this, *it, sz, opts);
+    for (UIntSet::iterator it = activeImgs.begin(); it != activeImgs.end(); ++it)
+    {
         remapped.setPanoImage(panorama.getSrcImage(*it), opts, vigra::Rect2D(0,0,360,180));
         // calculate alpha channel
         remapped.calcAlpha();
@@ -101,15 +92,13 @@ void CenterHorizontally::centerHorizontically(PanoramaData& panorama)
                            vigra_ext::applyRect(remapped.boundingBox(),
                                                 destImage(panoAlpha)));
         }
-    //    vigra::ImageExportInfo imge("c:/hugin_calcfov_alpha.png");
-    //    exportImage(vigra::srcImageRange(panoAlpha), imge);
     
     // get field of view
     std::vector<int> borders;
     bool colOccupied = false;
     for (int h=0; h < 360; h++) {
         bool curColOccupied = false;
-        for (int v=0; v< 180; v++) {
+        for (int v=0; v< 180 && !curColOccupied; v++) {
             if (panoAlpha(h,v)) {
                 // pixel is valid
                 curColOccupied = true;
@@ -125,7 +114,7 @@ void CenterHorizontally::centerHorizontically(PanoramaData& panorama)
     }
     
     
-    int lastidx = borders.size() -1;
+    const int lastidx = borders.size() -1;
     if (lastidx == -1) {
         // empty pano
         return;
@@ -133,6 +122,11 @@ void CenterHorizontally::centerHorizontically(PanoramaData& panorama)
     
     if (colOccupied) {
         // we have reached the right border, and the pano is still valid
+        if (borders.size() == 1 && borders[0] == -180)
+        {
+            // pano covers full range, nothing to do
+            return;
+        };
         // shift right fragments by 360 deg
         // |11    2222|  -> |      222211     |
         std::vector<int> newBorders;
@@ -143,41 +137,10 @@ void CenterHorizontally::centerHorizontically(PanoramaData& panorama)
         borders = newBorders;
     }
     
-    double dYaw=(borders[0] + borders[lastidx])/2;
+    const double dYaw=(borders[0] + borders[lastidx])/2;
     
-    // apply yaw shift
-    unsigned int nImg = panorama.getNrOfImages();
-    for (unsigned int i=0; i < nImg; i++) {
-        const SrcPanoImage & image = panorama.getImage(i);
-        // only adjust yaw if we haven't already done so because of linking.
-        bool update=true;
-        if(image.YawisLinked())
-        {
-            for(unsigned int j=0; j<i; j++)
-            {
-                if(image.YawisLinkedWith(panorama.getImage(j)))
-                {
-                    update=false;
-                    break;
-                };
-            };
-        };
-        if (update)
-        {
-            double yaw = image.getYaw();
-            yaw = yaw - dYaw;
-            while (yaw < 180) {
-                yaw += 360;
-            }
-            while (yaw > 180) {
-                yaw -= 360;
-            }
-            SrcPanoImage newImage = image;
-            newImage.setYaw(yaw);
-            panorama.setImage(i, newImage);
-            panorama.imageChanged(i);
-        }
-    }
+    // apply yaw shift, takes also translation parameters into account
+    RotatePanorama(panorama, -dYaw, 0, 0).run();
 }
 
 } ///namespace
