@@ -222,7 +222,8 @@ std::string doubleToString(double d, int digits)
     if (digits < 0) {
         strcpy(fmt,"%f");
     } else {
-        std::sprintf(fmt,"%%.%df",digits);
+        // max. 16 digits to prevent overflow
+        std::sprintf(fmt, "%%.%df", std::min(digits, 16));
     }
     char c[1024];
     c[1023] = 0;
@@ -608,9 +609,15 @@ void DestroyContext()
 static GLuint GlutWindowHandle;
 bool CreateContext(int *argcp, char **argv)
 {
+    // GLUT changes the working directory to the ressource path of the bundle
+    // so we store the old working directory and restore it at the end
+    char workingDir[FILENAME_MAX];
+    getcwd(workingDir, FILENAME_MAX);
     glutInit(argcp, argv);
     glutInitDisplayMode(GLUT_SINGLE | GLUT_RGBA | GLUT_ALPHA);
     GlutWindowHandle = glutCreateWindow("Hugin");
+    // restore working dir, as GLUT changes it the ressource path
+    chdir(workingDir);
     return true;
 }
 
