@@ -32,6 +32,8 @@
 #include <iostream>
 #include <sstream>
 #include <cassert>
+#include <vigra/imageinfo.hxx>
+#include <lcms2.h>
 
 #include <hugin_utils/platform.h>
 
@@ -68,60 +70,15 @@
     #define DEBUG_NOTICE(msg)
 #endif
 
-// when an error occured, but can be handled by the same function
+// when an error occurred, but can be handled by the same function
 #define DEBUG_WARN(msg) { std::cerr << "WARN: " << DEBUG_HEADER << msg << std::endl; }
-// an error occured, might be handled by a calling function
+// an error occurred, might be handled by a calling function
 #define DEBUG_ERROR(msg) { std::cerr << "ERROR: " << DEBUG_HEADER << msg << std::endl; }
-// a fatal error occured. further program execution is unlikely
+// a fatal error occurred. further program execution is unlikely
 #define DEBUG_FATAL(msg) { std::cerr << "FATAL: " << DEBUG_HEADER << "(): " << msg << std::endl; }
 // C-style assertion
 #define DEBUG_ASSERT(cond) assert(cond)
 
-
-// use trace function under windows, because usually there is
-// no stdout under windows
-#ifdef __WXMSW__
-    #ifdef DEBUG
-        #undef DEBUG_TRACE
-        #undef DEBUG_DEBUG
-        #undef DEBUG_INFO
-        #undef DEBUG_NOTICE
-
-        // debug trace
-//      #define DEBUG_TRACE(msg) { std::stringstream o; o << "TRACE " << DEBUG_HEADER << msg; wxLogDebug(o.str().c_str());}
-        #define DEBUG_TRACE(msg) { std::cerr << "TRACE " << DEBUG_HEADER << msg << std::endl; }
-        // low level debug info
-//      #define DEBUG_DEBUG(msg) { std::stringstream o; o << "DEBUG " << DEBUG_HEADER << msg; wxLogDebug(o.str().c_str()); }
-        #define DEBUG_DEBUG(msg) { std::cerr << "DEBUG " << DEBUG_HEADER << msg << std::endl; }
-        // informational debug message,
-//      #define DEBUG_INFO(msg) { std::stringstream o; o << "INFO " << DEBUG_HEADER << msg; wxLogDebug(o.str().c_str()); }
-        #define DEBUG_INFO(msg) { std::cerr << "INFO " << DEBUG_HEADER << msg << std::endl; }
-        // major change/operation should use this
-//      #define DEBUG_NOTICE(msg) { std::stringstream o; o << "NOTICE " << DEBUG_HEADER << msg; wxLogMessage(o.str().c_str()); }
-        #define DEBUG_NOTICE(msg) { std::cerr << "NOTICE " << DEBUG_HEADER << msg << std::endl; }
-    #endif
-    
-    #undef DEBUG_WARN
-    #undef DEBUG_ERROR
-    #undef DEBUG_FATAL
-    #undef DEBUG_ASSERT
-
-    // when an error occured, but can be handled by the same function
-    #define DEBUG_WARN(msg) { std::stringstream o; o << "WARN: " << DEBUG_HEADER << msg; wxLogWarning(wxString(o.str().c_str(), wxConvISO8859_1));}
-    // an error occured, might be handled by a calling function
-    #define DEBUG_ERROR(msg) { std::stringstream o; o << "ERROR: " << DEBUG_HEADER << msg; wxLogError(wxString(o.str().c_str(),wxConvISO8859_1));}
-    // a fatal error occured. further program execution is unlikely
-    #define DEBUG_FATAL(msg) { std::stringstream o; o << "FATAL: " << DEBUG_HEADER << "(): " << msg; wxLogError(wxString(o.str().c_str(),wxConvISO8859_1)); }
-    // assertion
-    #define DEBUG_ASSERT(cond) \
-        do { \
-            if (!(cond)) { \
-                std::stringstream o; o << "ASSERTATION: " << DEBUG_HEADER << "(): " << #cond; \
-                    wxLogFatalError(wxString(o.str().c_str(),wxConvISO8859_1)); \
-            } \
-        } while(0)
-#endif
-
 //
 #define UTILS_THROW(class, msg)  { std::stringstream o; o <<  msg; throw(class(o.str().c_str())); };
 
@@ -251,6 +208,12 @@ namespace hugin_utils
     /** returns the full absolute filename */
     IMPEX std::string GetAbsoluteFilename(const std::string& filename);
 
+    /** return true, if file type by extension is supported by vigra */
+    IMPEX bool IsFileTypeSupported(const std::string& filename);
+
+    /** check if filename contains extension, if not add default extension */
+    IMPEX void EnforceExtension(std::string& filename, const std::string& defaultExtension);
+
     /** returns the full path to the data directory */
     IMPEX std::string GetDataDir();
 
@@ -268,6 +231,9 @@ namespace hugin_utils
     IMPEX bool wrapupGPU();
     /** return a string with version numbers */
     IMPEX std::string GetHuginVersion();
+    /** returns description of given icc profile */
+    IMPEX std::string GetICCDesc(const vigra::ImageImportInfo::ICCProfile& iccProfile);
+    IMPEX std::string GetICCDesc(const cmsHPROFILE& profile);
 
 } // namespace
 
