@@ -153,7 +153,7 @@ void SetGeometricControlPointsUnconnected(HuginBase::Panorama& pano, const int m
     };
 
     // have we found unconnected images?
-    if(imgsToTest.size()==0)
+    if(imgsToTest.empty())
     {
         std::cout << "No unconnected images found." << std::endl
              << "No control point added." << std::endl;
@@ -385,12 +385,6 @@ int main(int argc, char* argv[])
         return 1;
     }
 
-    if(pano.getNrOfImages()==0)
-    {
-        std::cerr << "error: project file does not contains any image" << std::endl
-            << "aborting processing" << std::endl;
-        return 1;
-    };
     if(pano.getNrOfImages()==1)
     {
         std::cerr << "error: project file contains only one image" << std::endl
