@@ -222,12 +222,6 @@ int main(int argc, char* argv[])
         return 1;
     }
 
-    if(pano.getNrOfImages()==0)
-    {
-        std::cerr << "Error: project file does not contains any image" << std::endl;
-        return 1;
-    };
-
     //read masks and apply
     for(size_t i=0; i<maskFiles.size(); i++)
     {
@@ -238,7 +232,7 @@ int main(int argc, char* argv[])
             HuginBase::MaskPolygonVector loadedMasks;
             LoadMaskFromStream(in, maskImageSize, loadedMasks, maskFiles[i].imageNr);
             in.close();
-            if(maskImageSize.area()==0 || loadedMasks.size()==0)
+            if(maskImageSize.area()==0 || loadedMasks.empty())
             {
                 std::cerr << "Error: Could not parse mask from file \"" << maskFiles[i].maskFile << "\"." << std::endl;
                 return 1;
